@@ -77,7 +77,11 @@ def create_check_arguments(
     nonexistent directories. It is idempotent though, since it does not alter
     any filesystem state.
     """
-    source_paths = backend_arguments.get_source_path_for_check(configuration)
+    source_paths = backend_arguments.get_source_path_for_check(
+        configuration,
+        kill_buck_after_build=False,
+        number_of_buck_threads=None,
+    )
 
     logging_sections = check_arguments.logging_sections
     additional_logging_sections = (
@@ -118,6 +122,7 @@ def create_check_arguments(
             debug=check_arguments.debug,
             enable_readonly_analysis=configuration.get_enable_readonly_analysis(),
             enable_strict_override_check=configuration.get_enable_strict_override_check(),
+            enable_strict_any_check=configuration.get_enable_strict_any_check(),
             enable_unawaited_awaitable_analysis=(
                 configuration.get_enable_unawaited_awaitable_analysis()
             ),
