@@ -719,7 +719,11 @@ def create_infer_arguments(
     nonexistent directories. It is idempotent though, since it does not alter
     any filesystem state.
     """
-    source_paths = backend_arguments.get_source_path_for_check(configuration)
+    source_paths = backend_arguments.get_source_path_for_check(
+        configuration,
+        kill_buck_after_build=infer_arguments.kill_buck_after_build,
+        number_of_buck_threads=infer_arguments.number_of_buck_threads,
+    )
 
     log_directory = configuration.get_log_directory()
     profiling_output = (
